#
# spec file for package aegisub
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffms2
%bcond_with perl
%bcond_with ruby

Name:           aegisub
Version:        2.1.9
Release:        6.2
Summary:        Subtitle editor
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://www.aegisub.net/
Source0:        http://ftp.aegisub.org/pub/releases/aegisub-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE aegisub-2.1.9-system_libs.patch reddwarf@opensuse.org -- Use system libraries instead of included ones
Patch0:         aegisub-2.1.9-system_libs.patch
# PATCH-FIX-UPSTREAM aegisub-2.1.8.99.rev5789-ld.patch reddwarf@opensuse.org -- Link against librt. Fixed upstream.
Patch1:         aegisub-2.1.8.99.rev5789-ld.patch
# PATCH-FIX-UPSTREAM aegisub-2.1.9-underlinking.patch reddwarf@opensuse.org -- Link against libz, Fixed upstream.
Patch2:         aegisub-2.1.9-underlinking.patch
# PATCH-FIX-UPSTREAM aegisub-2.1.9-no_glu.patch http://devel.aegisub.org/ticket/1511 reddwarf@opensuse.org -- Don't ask for GLU since it's not being used
Patch3:         aegisub-2.1.9-no_glu.patch
BuildRequires:  ImageMagick
BuildRequires:  boost-devel >= 1.34
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  pkg-config >= 0.20
BuildRequires:  update-desktop-files
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
BuildRequires:  wxWidgets-devel >= 2.8.1
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fontconfig) >= 2.4
BuildRequires:  pkgconfig(freetype2) >= 9.7.0
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(hunspell) >= 1.2.0
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libpulse) >= 0.5
BuildRequires:  pkgconfig(lua) < 5.2
BuildRequires:  pkgconfig(lua) >= 5.1
BuildRequires:  pkgconfig(openal)
%if %{with ffms2}
BuildRequires:  pkgconfig(ffms2)
%endif
%if %{with perl}
BuildRequires:  perl >= 5.004
Requires:       perl = %{perl_version}
%endif
%if %{with ruby}
BuildRequires:  ruby-devel >= 1.8
%endif

%description
Aegisub is an advanced subtitle editor for Windows, and UNIX-like systems, such
as Linux, Mac OS X and BSD. It is open source software and free for any use.

Aegisub natively works with the Advanced SubStation Alpha format (aptly
abbreviated ASS) which allows for many advanced effects in the subtitles, apart
from just basic timed text. Aegisub's goal is to support using these advanced
functions with ease.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3
rm -r src/boost
rm -r src/gl
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/version.cpp
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/version.cpp

%build
%configure \
  %{!?with_ruby:--without-ruby} \
  %{!?with_perl:--without-perl} \
  --with-player-audio=pulseaudio \
  --docdir='%{_docdir}'
make %{?_smp_mflags}

%install
%make_install
%suse_update_desktop_file %{name}
%find_lang %{name}21

%files -f %{name}21.lang
%defattr(0644, root, root, 0755)
%{_docdir}/%{name}
%attr(0755,root,root) %{_bindir}/%{name}-2.1
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*

%changelog
* Fri Sep 21 2012 reddwarf@opensuse.org
- Add aegisub-2.1.9-no_glu.patch
- Remove explicit glu dependency.
  wxWidgets-devel is the one that should have it
- Remove explicit xfixes,xdamage and xxf86vm dependencies.
  Mesa-libGL-devel is the one that should be fixed (probably removing the .la file)
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu,xfixes,xdagame and xxf86vm dependency
* Fri Feb 10 2012 reddwarf@opensuse.org
- Update to 2.1.9
* Sat Oct 29 2011 reddwarf@opensuse.org
- Update to 2.1.9 rev5789
* Sun Jul  5 2009 reddwarf@opensuse.org
- First package
